# Chewie

[![Build Status](https://travis-ci.com/faucetsdn/chewie.svg?branch=master)](https://travis-ci.com/faucetsdn/chewie)
[![Maintainability](https://api.codeclimate.com/v1/badges/66b6e93ba93b6ac56d17/maintainability)](https://codeclimate.com/github/faucetsdn/chewie/maintainability)
[![Test Coverage](https://api.codeclimate.com/v1/badges/66b6e93ba93b6ac56d17/test_coverage)](https://codeclimate.com/github/faucetsdn/chewie/test_coverage)

Chewie is an EAPOL/802.1x implementation in Python.

Currently barely works, useful if you have one user and their password is "microphone"

More information at https://github.com/faucetsdn/chewie
